#
# spec file for package netcdf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global flavor gnu-openmpi2-hpc%{nil}

%define _do_check 1

%define ver 4.6.1
%define _ver 4_6_1
%define pname netcdf

%if 0%{?is_opensuse} || 0%{?is_backports}
%undefine DisOMPI3
%else
%define DisOMPI3 ExclusiveArch:  do_not_build
%endif

%if "%flavor" == ""
%define package_name %{pname}
ExclusiveArch:  do_not_build
%endif

ExcludeArch:    s390 s390x

%if "%{flavor}" == "serial"
%bcond_with hpc
%endif

%if "%{flavor}" == "gnu-hpc"
%global compiler_family gnu
%undefine c_f_ver
%undefine mpi_flavor 
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu-openmpi-hpc"
%{?DisOMPI1}
%global compiler_family gnu
%undefine c_f_ver
%define mpi_flavor openmpi
%define mpi_ver 1
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu-openmpi3-hpc"
%{?DisOMPI3}
%global compiler_family gnu
%undefine c_f_ver
%define mpi_flavor openmpi
%define mpi_ver 3
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu-openmpi2-hpc"
%{?DisOMPI2}
%global compiler_family gnu
%undefine c_f_ver
%define mpi_flavor openmpi
%define mpi_ver 2
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu-mvapich2-hpc"
%global compiler_family gnu
%undefine c_f_ver
%define mpi_flavor mvapich2
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu-mpich-hpc"
%global compiler_family gnu
%undefine c_f_ver
%define mpi_flavor mpich
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu7-hpc"
%global compiler_family gnu
%define c_f_ver 7
%undefine mpi_flavor 
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu7-openmpi-hpc"
%{?DisOMPI1}
%global compiler_family gnu
%define c_f_ver 7
%define mpi_flavor openmpi
%define mpi_ver 1
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu7-openmpi3-hpc"
%{?DisOMPI3}
%global compiler_family gnu
%define c_f_ver 7
%define mpi_flavor openmpi
%define mpi_ver 3
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu7-mvapich2-hpc"
%global compiler_family gnu
%define c_f_ver 7
%define mpi_flavor mvapich2
%bcond_without hpc
%endif

%if "%{flavor}" == "gnu7-mpich-hpc"
%global compiler_family gnu
%define c_f_ver 7
%define mpi_flavor mpich
%bcond_without hpc
%endif

%if "%{flavor}" == "mvapich2"
%define mpi_flavor mvapich2
%bcond_with hpc
%endif

%if "%{flavor}" == "openmpi"
%define mpi_flavor openmpi
%bcond_with hpc
%endif

%{?mpi_flavor:%{bcond_without mpi}}%{!?mpi_flavor:%{bcond_with mpi}}
%{?with_hpc:%{!?compiler_family:%global compiler_family gnu}}
%{?with_mpi:%{!?mpi_flavor:%global mpi_flavor openmpi}}

%if %{with hpc}
%{hpc_init -c %compiler_family %{?c_f_ver:-v %{c_f_ver}} %{?with_mpi:-m {%mpi_flavor}} %{?mpi_ver:-V %{mpi_ver}} %{?ext:-e %{ext}}}
%define package_name %{hpc_package_name %_ver}
%define libname(s:)   lib%{pname}%{hpc_package_name_tail %_ver}
%define p_prefix %hpc_prefix
%define p_bindir %hpc_bindir
%define p_libdir %hpc_libdir
%define p_mandir %hpc_mandir
%define p_includedir %hpc_includedir
%else
%define package_name %{pname}%{p_suffix}
%define libname(s:)   lib%{pname}%{-s*}%{?p_suffix}
 %if %{without mpi}
%define p_prefix %_prefix
%define p_bindir %_bindir
%define p_libdir %_libdir
%define p_mandir %_mandir
%define p_includedir %_includedir
 %else
%define p_prefix /usr/%{_lib}/mpi/gcc/%{mpi_flavor}
%define p_bindir %{p_prefix}/bin
%define p_libdir %{p_prefix}/%{_lib}
%define p_mandir %{p_prefix}/share/man
%define p_includedir %{p_prefix}/include
 %endif
%endif
%define p_suffix %{?with_mpi:-%{mpi_flavor}}
%define hdf5_module_file %{?with_mpi:p}hdf5

Name:           %{package_name}
Summary:        Command-line programs for the NetCDF scientific data format
License:        NetCDF
Group:          Productivity/Scientific/Other
Version:        %ver
Release:        lp151.6.6.1
%define sonum   13
Url:            http://www.unidata.ucar.edu/software/netcdf/
Source:         ftp://ftp.unidata.ucar.edu/pub/%{pname}/%{pname}-%{version}.tar.gz
Source1:        nc-config.1.gz
Source100:      netcdf-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gawk
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  pkg-config
BuildRequires:  zlib-devel >= 1.2.5
%ifarch %ix86 x86_64 ppc ppc64 s390x armv7l
BuildRequires:  valgrind
%endif
BuildRequires:  libcurl-devel >= 7.18.0
%if %{without hpc}
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
# Note hdf5 1.10 has incompatible on disk files
BuildRequires:  hdf5%{p_suffix}-devel
BuildRequires:  libhdf5_hl%{p_suffix}
 %if %{with mpi}
BuildRequires:  %{mpi_flavor}-devel
 %endif
%else
BuildRequires:  %{compiler_family}%{?c_f_ver}-compilers-hpc-macros-devel
BuildRequires:  hdf5-%{compiler_family}%{?c_f_ver}%{?with_mpi:-%{mpi_flavor}%{?mpi_ver}}-hpc-devel
BuildRequires:  lua-lmod
BuildRequires:  suse-hpc
 %if %{with mpi}
BuildRequires:  %{mpi_flavor}%{?mpi_ver}-%{compiler_family}%{?c_f_ver}-hpc-macros-devel
 %endif
%endif
Requires:       %{libname -s %{sonum}} = %{version}

%description
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

%if %{without mpi}
This package contains utility functions for working with NetCDF files.
%else
This package contains the %{mpi_flavor} version of utility functions for
working with NetCDF files.
%endif

%{?with_hpc:%{hpc_master_package}}

%package -n     %{libname -s %{sonum}}
Summary:        Shared libraries for the NetCDF scientific data format
Group:          Productivity/Scientific/Other
%if %{without mpi} && %{without hpc}
Provides:       %{libname}-4 = %{version}
Obsoletes:      %{libname}-4 < %{version}
%endif
# To avoid unresolvable errors due to multiple providers of the library
%{!?with_hpc:Provides:       %{libname} = %{version}}
Obsoletes:      %{libname} < %{version}
%if %{without hpc}
Requires:       libhdf5%{p_suffix}
Requires:       libhdf5_hl%{p_suffix}
%else
%{hpc_requires}
Requires:       libhdf5%{hpc_package_name_tail} >= 1.8.8
Requires:       libhdf5_hl%{hpc_package_name_tail} >= 1.8.8
%endif

%description -n %{libname -s %{sonum}}
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a collection of software libraries
for C, Fortran, C++, and Perl that provides an implementation of the
interface. The NetCDF library also defines a machine-independent
format for representing scientific data. Together, the interface,
library, and format support the creation, access, and sharing of
scientific data.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

%if %{without mpi}
This package contains the NetCDF runtime libraries.
%else
This package contains the %{mpi_flavor} versuib if the NetCDF runtime
libraries.
%endif

%{?with_hpc:%{hpc_master_package -L -l}}

%package   devel-data
Summary:        Development data files for %{name}
Group:          Development/Libraries/C and C++
Provides:       %{pname}-rpm-macros = %version
Conflicts:      otherproviders(%{pname}-rpm-macros)

%description devel-data
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

This package contains generic files needed to create projects that use
any version of NetCDF.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname -s %{sonum}} = %{version}
%{!?with_hpc:Requires:       %{name}-devel-data = %{version}}
Requires:       libcurl-devel >= 7.18.0
Requires:       pkgconfig
Requires:       zlib-devel >= 1.2.5
%if %{without hpc}
Requires:       hdf5%{p_suffix}-devel >= 1.8.8
%{?with_mpi:Requires:       %{mpi_flavor}-devel}
%else
%{hpc_requires_devel}
Requires:       hdf5%{hpc_package_name_tail}-devel >= 1.8.8
%endif

%description devel
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

%if %{with mpi}
This package contains all files needed to create projects that use NetCDF.
%else
This package contains all files needed to create projects that use
the %{mpi_flavor} version of NetCDF.
%endif

%{?with_hpc:%{hpc_master_package devel}}

%package devel-static
Summary:        Static development files for %{name}
Group:          Development/Libraries/C and C++
%if %{without hpc}
Requires:       hdf5%{p_suffix}-devel >= 1.8.8
%else
Requires:       %{name}-devel = %{version}
%endif
Requires:       libcurl-devel >= 7.18.0
Requires:       zlib-devel >= 1.2.5

%description devel-static
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

%if %{without mpi}
This package contains the static libraries for NetCDF.
%else
This package contains the %{mpi_flavor} versions of the static libraries 
for NetCDF.
%endif

%prep
%{?with_hpc:%hpc_debug}
%setup -q -n %{pname}-%{version}
m4 libsrc/ncx.m4 > libsrc/ncx.c

# Create baselib.conf dynamically (non-HPC build only).
%if %{without hpc}
cat > %{_sourcedir}/baselibs.conf  <<EOF
%{libname -s %{sonum}}
EOF
%endif

# Fix spurious-executable-perm RPMLINT warning
chmod a-x RELEASE_NOTES.md

%build
%{?with_hpc:%{hpc_setup}}
%{?with_hpc:module load %{hdf5_module_file}}

%if %{without mpi}
export CC=gcc CXX=g++ FC=gfortran
%else
export CC=%{!?with_hpc:/usr/%_lib/mpi/gcc/%{mpi_flavor}/bin/}mpicc 
export FC=%{!?with_hpc:/usr/%_lib/mpi/gcc/%{mpi_flavor}/bin/}mpif90 
export CXX=%{!?with_hpc:/usr/%_lib/mpi/gcc/%{mpi_flavor}/bin/}mpic++
%endif
autoreconf -fv
export CFLAGS="-fno-strict-aliasing %{?with_hpc:-L$HDF5_LIB -I$HDF5_INC}"
export CXXFLAGS="%{optflags} %{?with_hpc:-L$HDF5_LIB -I$HDF5_INC}"
export FCFLAGS="%{optflags} %{?with_hpc:-L$HDF5_LIB -I$HDF5_INC}"
%{?with_hpc:export LDFLAGS="-L$HDF5_LIB"}
%if %{without hpc}
%configure \
     --prefix=%{p_prefix} \
     --bindir=%{p_bindir} \
     --libdir=%{p_libdir} \
     --includedir=%{p_includedir} \
     --mandir=%{p_mandir} \
%else
%hpc_configure \
%endif
    --enable-shared \
    --enable-netcdf-4 \
    --enable-dap \
    --enable-ncgen4 \
    --enable-extra-example-tests \
    --disable-dap-remote-tests \
    --with-pic \
    --disable-doxygen \
    --enable-static \

make %{?_smp_mflags}

%install
%{?with_hpc:%{hpc_setup}}
%{?with_hpc:module load %{hdf5_module_file}}

%{?with_hpc:export CFLAGS="-L$HDF5_LIB -I$HDF5_INC"}
make install DESTDIR="%{buildroot}"

mkdir -p %{buildroot}%{_mandir}/man1
install -m644 %{S:1} %{buildroot}%{p_mandir}/man1
rm -f %{buildroot}%{p_libdir}/*.la

# install netcdf_par.h which is skipped when mpicc in not detected
install -m644 include/netcdf_par.h %{buildroot}%{p_includedir}/netcdf_par.h

%if %{without hpc}
# rpm macro for version checking
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat > %{buildroot}%{_sysconfdir}/rpm/macros.netcdf <<EOF
#
# RPM macros for hdf5 packaging
#
%_netcdf_sonum  %{sonum}
%_netcdf_version  %{version}
EOF
 %if %{with mpi}
# Module files 
mkdir -p %{buildroot}%{_datadir}/modules/%{pname}-%{mpi_flavor}
cat << EOF > %{buildroot}%{_datadir}/modules/%{pname}-%{mpi_flavor}/%version
#%%Module
proc ModulesHelp { } {
        global dotversion
        puts stderr "\tLoads the %{pname}-%{mpi_flavor} %version Environment"
}

module-whatis  "Loads the %{pname}-%{mpi_flavor} %version Environment."
prepend-path    PATH                %{p_bindir}
prepend-path    MANPATH             %{p_mandir}
prepend-path    LD_LIBRARY_PATH     %{p_libdir}
prepend-path    LIBRARY_PATH        %{p_libdir}
prepend-path    CPATH               %{p_includedir}
prepend-path    C_INCLUDE_PATH      %{p_includedir}
prepend-path    CPLUS_INCLUDE_PATH  %{p_includedir}
EOF

 %endif
%else
%hpc_write_modules_files
#%%Module1.0#####################################################################

proc ModulesHelp { } {

puts stderr " "
puts stderr "This module loads the NetCDF C API built with the %{compiler_family} compiler"
puts stderr "toolchain and the %{mpi_flavor} MPI stack."
puts stderr " "
puts stderr "Note that this build of NetCDF leverages the HDF I/O library and requires linkage"
puts stderr "against hdf5. Consequently, the phdf5 package is loaded automatically with this module."
puts stderr "A typical compilation step for C applications requiring NetCDF is as follows:"
puts stderr " "
puts stderr "\\\$CC -I\\\$NETCDF_INC app.c -L\\\$NETCDF_LIB -lnetcdf -L\\\$HDF5_LIB -lhdf5"

puts stderr "\nVersion %{version}\n"

}
module-whatis "Name: %{hpc_upcase %pname} built with %{compiler_family} toolchain"
module-whatis "Version: %{version}"
module-whatis "Category: runtime library"
module-whatis "Description: %{SUMMARY:0}"
module-whatis "%{url}"

set             version             %{version}

# Require phdf5

if [ expr [ module-info mode load ] || [module-info mode display ] ] {
    if {  ![is-loaded %{hdf5_module_file}]  } {
        module load %{hdf5_module_file}
    }
}

prepend-path    PATH                %{hpc_bindir}
prepend-path    MANPATH             %{hpc_mandir}
prepend-path    LD_LIBRARY_PATH     %{hpc_libdir}

setenv          %{hpc_upcase %pname}_DIR        %{hpc_prefix}
setenv          %{hpc_upcase %pname}_BIN        %{hpc_bindir}

if {[file isdirectory  %{hpc_includedir}]} {
prepend-path    LIBRARY_PATH        %{hpc_libdir}
prepend-path    CPATH               %{hpc_includedir}
prepend-path    C_INCLUDE_PATH      %{hpc_includedir}
prepend-path    CPLUS_INCLUDE_PATH  %{hpc_includedir}
prepend-path    INCLUDE                         %{hpc_includedir}
%hpc_modulefile_add_pkgconfig_path

setenv          %{hpc_upcase %pname}_LIB        %{hpc_libdir}
setenv          %{hpc_upcase %pname}_INC        %{hpc_includedir}
}
EOF

%endif

%if 0%{?_do_check}
%check
%if %{with hpc}
%{hpc_setup}
module load %{hdf5_module_file}
%else
 %if %{with mpi}
 . /usr/%_lib/mpi/gcc/%{mpi_flavor}/bin/mpivars.sh
 %endif
%endif
    make check
%endif

%if %{with hpc} || %{with mpi}
%define ldconfig_args -N %p_libdir
%endif

%post -n %{libname -s %{sonum}}
/sbin/ldconfig %{?ldconfig_args}

%postun -n %{libname -s %{sonum}} 
/sbin/ldconfig %{?ldconfig_args}
%{?with_hpc:%hpc_module_delete_if_default}

%files
%defattr(-,root,root,-)
%doc COPYRIGHT README.md RELEASE_NOTES.md
%{?with_hpc:%dir %hpc_datadir}
%{?with_hpc:%dir %p_mandir}
%{p_bindir}%{!?with_hpc:/*}
%exclude %{p_bindir}/nc-config
%{p_mandir}/man1%{!?with_hpc:/*}

%files -n %{libname -s %{sonum}}
%defattr(-,root,root,-)
%if %{with hpc}
%hpc_dirs
%hpc_modules_files
%else
 %if %{with mpi}
%dir %{_datadir}/modules
%{_datadir}/modules/%{pname}-%{mpi_flavor}
 %endif
%endif
%{p_libdir}/libnetcdf.so.*

%if %{without hpc}
%files devel-data
%defattr(-,root,root,-)
%config %{_sysconfdir}/rpm/macros.netcdf
%endif

%files devel
%defattr(-,root,root,-)
%{p_bindir}/nc-config
%{p_includedir}%{!?with_hpc:/*}
%{p_libdir}/*.so
%{?with_hpc:%hpc_pkgconfig_file}
%{p_libdir}/pkgconfig/netcdf.pc
%{p_mandir}/man3%{!?with_hpc:/*}
%{p_libdir}/libnetcdf.settings

%files devel-static
%defattr(-,root,root,-)
%{p_libdir}/libnetcdf.a

%changelog
* Mon Jul 20 2020 Egbert Eich <eich@suse.com>
- Remove requirements for parallel-netcdf from non-HPC builds:
  without the '--enable-pnetcdf' configure option, this doesn't
  make sense.
* Mon Jul 20 2020 Egbert Eich <eich@suse.com>
- Remove build restrictions for SLE builds: build all flavors for
  SLE.
- Fix ldconfig args for HPC packages: no caching should be done
  as these libs are made available thru LD_LIBRARY_PATH tweaking.
- Adhere to common conventions regarding NetCDF and PnetCDF:
  NetCDF modules should be called 'netcdf' - regardless whether
  they are 'serial' or use MPI (boo#1174291).
* Tue May  8 2018 adrian@suse.de
- go back to hdf5 1.10
* Mon Apr 30 2018 eich@suse.com
- Fix devel-data package conflicts by a Provides/Conflicts that
  doesn't collide with a package name.
* Mon Apr 30 2018 eich@suse.com
- Remove the 'ring magic' as this seems to create issues during
  verification.
* Mon Apr 30 2018 eich@suse.com
- (Temporarily) disable fpr S390* as a check test fails currently
  on BE.
* Mon Apr 30 2018 eich@suse.com
- Fix dependency issues with non-HPC devel packages and
  devel-data.
* Mon Apr 30 2018 eich@suse.com
- Add a dependency to the HPC master package of the correct
  flavor of libhdf5_hl (bsc#1091243).
* Tue Apr 24 2018 jberry@suse.com
- Avoid file conflict between devel-data packages over rpm macros.
* Wed Apr 11 2018 eich@suse.com
- Disable non-HPC builds on non-openSUSE systems:
  a. currently only SUSE products/projects are supported/
  b. non-HPC builds are not and have never been supported on SLE,
    on openSUSE they are provided for compatibility reasons.
* Wed Apr  4 2018 adrian@suse.de
- update to version 4.6.1 (FATE#325561)
  * changes since 4.4.4.1 are documented here:
    https://www.unidata.ucar.edu/blogs/news/entry/netcdf-4-6-1
    https://www.unidata.ucar.edu/blogs/news/entry/netcdf-4-6-0
    https://www.unidata.ucar.edu/blogs/news/entry/netcdf-4-5-0
- Obsoletes all patches:
  netcdf-disable-szip-linking.patch
  netcdf-h5-test-fix-type-mismatch.patch
  netcdf-no_date_time.patch
- drop hdf4 support
- use version 1.8 of hdf5 in non-hpc mode to avoid incompatible
  on-disk data
* Fri Feb  9 2018 eich@suse.com
- Add support for openmpi2 for HPC (FATE#325089).
* Fri Feb  9 2018 cgoll@suse.com
- Fix summary in module files (bnc#1080259)
* Fri Jan 19 2018 eich@suse.com
- Change the name of the MPI version of the module file directory
  to pnetcdf to distinguish it from the 'serial' one (boo#1075933).
* Fri Jan 12 2018 eich@suse.com
- Disable the openmpi3 flavor in some products.
* Fri Jan  5 2018 eich@suse.com
- Switch from gcc6 to gcc7 as additional compiler flavor for HPC on SLES.
- Add support for mpich and openmpi3 for HPC.
* Fri Nov 10 2017 eich@suse.com
- Add dependency on the hpdf5 library package
  to the netdf libary package.
* Thu Nov  2 2017 eich@suse.com
- Simplify Group: - do not destinguish between MPI
  and non-MPI: the IBS check scripts cannot handle
  this well.
* Mon Oct 30 2017 eich@suse.com
- Fix wrong Requires: in static package.
* Sat Oct 28 2017 eich@suse.com
- Add minimal mpi-selector support for non-HPC MPI build.
  This will avoid the MPI packages to conflict with the
  'serial' ones as both provide the same files and libs.
* Sat Oct 28 2017 eich@suse.com
- Fix botched dependency for libpnetcdf-<mpi-flavor>.
* Tue Oct 24 2017 jjolly@suse.com
- Added patch netcdf-h5-test-fix-type-mismatch.patch
  * Fixes type mismatch in test tst_h_dimscales
    (bsc#1064705).
* Thu Oct 19 2017 eich@suse.com
- Source mpivars.sh to fix the non-HPC openmpi %%check.
* Tue Oct 17 2017 eich@suse.com
- Add magic to limit the number of flavors built in the
  in the OBS ring.
* Wed Sep 13 2017 eich@suse.com
- Incorporated HPC-style builds using environment modules.
- Converted to multibuild (FATE#321719).
- renamed rpmlintrc to netcdf-rpmlintrc.
- Generate baselib.conf dynamically and only for the non-HPC
  build: this avoids issues with the source validator.
* Tue Sep 12 2017 badshah400@gmail.com
- Update to version 4.4.1.1:
  - Fixed an issue where ncgen would potentially crash or write
    incorrect netCDF4 binary data under very specific
    circumstances [gh#Unidata/netcdf-c#323].
  - Updated documentation related to netCDF variable names and
    DAP2 access to reflect the undefined behavior potentially
    observed when DAP2 reserved keywords are used as netCDF
    variable names.
  - Fixed an issue with nc_inq_type() not returning proper value
    in some circumstances [gh#Unidata/netcdf-c#317].
  - Corrected an issue related to test failures when
  - -disable-utilities or -DENABLE_UTILITIES=OFF are specified
    when building with autotools or cmake, respectively
    [gh#Unidata/netcdf-c#313].
  - Corrected a behavioral issue with the _NCProperties attribute
    taking up too much space [gh#Unidata/netcdf-c#300],
    [gh#Unidata/netcdf-c#301].
  - Corrected behavior for nc-config so that, if nf-config is
    found in system, the proper fortran-related information will
    be conveyed [gh#Unidata/netcdf-c#296].
- Add netcdf-disable-szip-linking.patch:  Disable building with
  szip support for now, since test nc_test4/tst_interops5.c fails
  otherwise; this is likely to be fixed with version 4.5.0 of
  netcdf, but requires big enough changes that we don't backport
  it here. Necessitates BuildRequires on libtool and running
  autoreconf before configure.
* Thu Feb  9 2017 dimstar@opensuse.org
- Explicitly BuildRequire m4
* Sat Aug  6 2016 wbauer@tmo.at
- Remove %%{optflags} from CFLAGS for now to fix build with hdf5-1.10
  in Factory, see https://github.com/Unidata/netcdf-c/issues/244
* Sun Jul 31 2016 virtuousfox@gmail.com
- Add 32bit version to satisfy libavfilter6-32bit
* Sun Jul 17 2016 jengelh@inai.de
- Trim descriptions. (libnetcdf11 will be the prominently installed
  one and therefore retains it mostly.)
* Fri Jul 15 2016 toddrme2178@gmail.com
- As far as I can find the settings file is only needed for
  development.
* Tue Jul  5 2016 adrian@suse.de
- update to version 4.4.1
  Details can be found in the RELEASE_NOTES file.
- Note: The combination of netCDF-C library versions earlier than
  4.4.1 and libhdf5 1.10.0+ should be avoided, as they will result
  in binary files not readable by systems using earlier libhdf5 versions.
* Thu Mar 31 2016 dvaleev@suse.com
- Regenerate ncx.c from ncx.m4. Tarball doesn't have fresh copy
  of it. https://github.com/Unidata/netcdf-c/issues/159
* Wed Mar 16 2016 toddrme2178@gmail.com
- Update to version 4.4.0.  Highlights:
  * Added CDM-5 support.
  * Added support for opening in-memory file content.
  * Modified CMakeLists.txt to work with the re-organized cmake
    configuration used by the latest HDF5, 1.8.16, on Windows.
    Before this fix, netCDF would fail to locate hdf5 1.8.16 when
    using cmake on Windows.
  * Modified ncgen to properly handle the L and UL suffixes for
    integer constants to keep backward compatibility.
- Remove netcdf-correct_casting.patch, rendered irrelevant by
  upstream change.
- Remov upstream-included netcdf-codecleanup.patch and
  netcdf-pkgconfig.patch
- Rebase netcdf-no_date_time.patch
* Sat Nov 21 2015 scorot@free.fr
- install netcdf_par.h which is skipped when mpicc in not detected
* Mon Aug 24 2015 toddrme2178@gmail.com
- Currently the regular, openmpi, and mpivachi2 versions of the
  library packages all provide the exact same libraries.  So any
  package built against the -devel package will end up with an
  "unresolvable" build error because there are multiple versions
  of the library it can use. To avoid this, I have added generic
  provides for the library package so packages can depend on the
  version they really need, avoiding these build issues.
- Depend on the correct regular, openmpi, and mpivachi2 versions of
  hdf, hdf5, and parallel-netcdf.
* Mon Jul 27 2015 toddrme2178@gmail.com
- Update subpackage groups
- Make subpackage summaries and descriptions more consistent
- Provide rpm macros for version identification
- Spec file cleanups
- Build parallel versions of the library.
* Fri Jul 24 2015 toddrme2178@gmail.com
- Build with HDF4 support
* Sat Apr 18 2015 p.drouand@gmail.com
- Update to version 4.3.3.1
  * When the NC_MPIPOSIX flag is given for parallel I/O access and
    the HDF5 library does not have the MPI-POSIX VFD configured in,
    the NC_MPIPOSIX flag is transparently aliased to the NC_MPIIO
    flag within the netCDF-4 library.
  * DAP requests now always include a restraint. Due to a problem in
    version 4.3.2, no constraint was generated when all variables were
    requested.
  * Fixed the code for handling character constants in datalists in
    ncgen. Two of the problems were:
  - It failed on large constants
  - It did not handle e.g.
  - var = 'a', 'b', …
    in the same way that ncgen3 did.
- Changes from version 4.3.3
  * Fixed bug resulting in error closing a valid netCDF-4 file with
    a dimension and a non-coordinate variable with the same name.
    [NCF-324](https://bugtracking.unidata.ucar.edu/browse/NCF-324)
  * Enabled previously-disabled shell-script-based tests for Visual
    Studio when `bash` is detected.
- Update netcdf-no_date_time.patch
* Tue Sep  2 2014 coolo@suse.com
- fix license for spdx 1.2
* Thu May  1 2014 ocefpaf@gmail.com
- update to 4.3.2
  * Improved type handling with respect to fill-values.
  * Enabled netCDF-4 bit-for-bit reproducibility for nccopy and other
    applications (thanks to Rimvydas Jasinskas and Quincey Koziol).
  * Improved cmake build process.
  * As part of an ongoing project, the Doxygen-generated netCDF documentation
    has been reorganized. The goal is to make the documentation easier to
    parse, and to eliminate redundant material.
* Mon Feb 10 2014 opensuse@dstoecker.de
- update to 4.3.1.1
  * Corrected a DAP issue reported by Jeff Whitaker related to
    non-conforming servers.
  * Corrected an issue with DAP tests failing in a 64-bit Cygwin
    environment. NCF-286
  * Add an extended format inquiry method to the netcdf API:
    nc_inq_format_extended. NC_HAVE_INQ_FORMAT_EXTENDED is defined
    in netcdf.h NCF-273
  * Fixed fill value handling for string types in nc4_get_vara().
  * Corrected behavior of nc_inq_unlimdim and nv_inq_unlimdims to
    report dimids in same order as nc_inq_dimids.
  * A number of previously-disabled unit tests were reviewed and
    made active.
  * When opening a netCDF-4 file, streamline the iteration over
    objects in the underlying HDF5 file.
  * Fixed netCDF-4 failure when renaming a dimension and renaming
    a variable using that dimension, in either order. NCF-177
  * When compiling with hdf4 support, both autotools and cmake-based
    builds now properly look for the libjpeg dependency and will link
    against it when found (or complain if it's not). Also added
    ENABLE_HDF4_FILE_TESTS option to CMake-based builds.
  * Fixed bug in ncgen; it was not properly filling empty string
    constants ("") to be the proper length. NCF-279
  * Fixed bug in ncgen where it was interpreting int64 constants as
    uint64 constants. NCF-278
  * Fixed bug in handling Http Basic Authorization. The code was
    actually there but was not being executed. NCF-277
  * Added hack to the DAP code to address a problem with the
    Columbia.edu server. That server does not serve up proper DAP2 DDS
    replies. The Dataset {...} name changes depending on if the request
    has certain kinds of constraints. NCF-276
  * Fixed bugs with ncdump annotation of values, using -b or -f
    options. NCF-275
  * Added better documentation about accessing ESG datasets. See
    http://www.unidata.ucar.edu/software/netcdf/docs/esg.html.
  * Corrected an issue with CMake-based builds enabling HDF4 support
    where the HDF4 libraries were in a non-standard location.
  * Fix bug introduced by NCF-267 where octal constants above '\177'
    were not recognized as proper octal constants. NCF-271
  * Fixed an issue where the netcdf.3 man page was not being installed
    by CMake-based builds. Github
  * Modify ncgen to support NUL characters in character array
    constants. NCF-267
  * Modify ncgen to support disambiguating references to an enum
    constant in a data list. NCF-265
  * Corrected bug in netCDF-4 dimension ID ordering assumptions,
    resulting in access that works locally but fails through DAP
    server. NCF-166
  * Ensure netCDF-4 compiles with OpenMPI as an alternative to
    MPICH2. NCF-160
  * Addressed issue with hanging Parallel netCDF-4 using HDF5 1.8.10.
    NCF-240
  * Removed deprecated directories:
    librpc/
    udunits/
    libcf/
    libcdmr/
  * Added configure and accompanying configuration files/templates to
    release repository. These will only be added to tagged releases
    on GitHub.
  * Integrated a fix by Quincey Koziol which addressed a variation of
    NCF-250, Fix issue of netCDF-4 parallel independent access with
    unlimited dimension hanging.
  * Integrated change contributed by Orion Poplawski which integrated
    GNUInstallDirs into the netCDF-C CMake system; this will permit
    systems that install into lib64 (such as Fedora) to make install
    without problem.
  * Corrected an error with the CMake config files that resulted in the
    netcdf.3 manpage not being built or installed.
  * Added nc_rename_grp to allow for group renaming in netCDF-4 files. NCF-204
  * Added a NC_HAVE_RENAME_GRP macro to netcdf.h, as per a request by
    Charlie Zender. This will allow software compiling against netcdf
    to easily query whether or not nc_rename_grp() is available.
  * Added Greg Sjaardema's contributed optimization for the nc4_find_dim_len
    function in libsrc4/nc4internal.c. The patch eliminates several
    malloc/free calls that exist in the original coding.
  * Added support for dynamic loading, to compliment the dynamic loading
    support introduced in hdf 1.8.11. Dynamic loading support depends on
    libdl, and is enabled as follows: NCF-258
    autotools-based builds: –enable-dynamic-loading
    cmake-based builds: -DENABLE_DYNAMIC_LOADING=ON
  * Fix issue of netCDF-4 parallel independent access with unlimited
    dimension hanging. Extending the size of an unlimited dimension in
    HDF5 must be a collective operation, so now an error is returned if
    trying to extend in independent access mode. NCF-250
  * Fixed bug with netCDF-4's inability to read HDF5 scalar numeric
    attributes. Also allow, in addition to zero length strings, a new
    NULL pointer as a string value. to improve interoperability with
    HDF5. This required a new CDL constant, 'NIL', that can be output
    from ncdump for such a string value in an HDF5 or netCDF-4 file.
    The ncgen utility was also modified to properly handle such NIL
    values for strings. NCF-56
  * Fix contributed by Nath Gopalaswamy to large file problem reading
    netCDF classic or 64-bit offset files that have a UINT32_MAX flag
    for large last record size of a variable that has values larger than
    1 byte. This problem had previously been fixed for writing such data,
    but was only tested with an ncbyte variable.
  * Fixed various minor documentation problems.
* Mon Oct 21 2013 toddrme2178@gmail.com
- Update to 4.3.0
  * fsync: Changed default in autotools config file; fsync must
    now be explicitely enabled instead of explicitely disabled.
  * Fixed netCDF-4 bug where odometer code for libdap2 mishandled
    stride > 1. Bug reported by Ansley Manke.
  * Fixed netCDF-4 bug where netCDF would ignore the HDF5 reference
    type in the file, instead of rejecting the file as it should.
  * Fixed netCDF-4 bug with particular order of creation of
    dimensions, coordinate variables, and subgroups resulting in
    two dimensions with the same dimension ID.
  * Fixed netCDF-4 bug with a multidimensional coordinate variable
    in a subgroup getting the wrong dimension IDs for its
    dimensions.
  * Fixed bug with incorrect fixed-size variable offsets in header
    getting written when schema changed for files created by
    parallel-netcdf. Thanks to Wei-keng Liao for developing and
    contributing the fix.
  * Fixed bug in handling old servers that do not do proper
    Grid to Structure conversions.
  * Replaced the oc library with oc2.0
  * Fix bug with nc_get_var1_uint() not accepting unsigned ints
    larger than 2**31.
  * Fix to convert occurrences of '/' in DAP names to %%2f.
  * Fix bug in netCDF-4 with scalar non-coordinate variables with
    same name as dimensions.
  * Fix bug in which calling netCDF-4 functions in which behavior
    that should not depend on order of calls sometimes produces
    the wrong results.
  * Merged in nccopy additions from Martin van Driel to support
  - g and -v options for specifying which groups or variables are
    to be copied.
  * Merged in parallel-netcdf bugs fixes from Greg Sjaardema.
  * Modify ncgen so that if the incoming file has a special
    attribute, then it is used to establish the special property of
    the netcdf file, but the attribute is not included as a real
    attribute in the file..
  * Added library version info to the user-agent string so that the
    server logs will be more informative.
  * Added work around for bad servers that sometimes sends DAP
    dataset with duplicate field names.
  * Fixed bug with strided access for NC_STRING type.
  * Prevented adding an invalid _FillValue attribute to a variable
    (with nonmatching type or multiple values), to avoid later
    error when any record variable is extended.
  * Fix bug in which some uses of vlen within compounds causes HDF5
    errors.
  * Fixed ncdump bug in display of data values of variables that use
    multiple unlimited dimensions.
  * Fix bug in which interspersing def_var calls with put_var calls
    can lead to corrupt metadata in a netCDF file with groups and
    inherited dimensions.
  * Building shared libraries works with DAP and netCDF4
    functionality.
  * 32-and-64-bit builds are working under MinGW on Windows.
  * Config.h for Windows compiles are included in the build.
  * NetCDF-4 dependency on NC_MAX_DIMS has been removed.
  * 64-bit DLL's are produced on Windows.
  * DLL Packaging issues are resolved.
  * The CMake build system (with related ctest and cdash systems
    for testing) has been integrated into netCDF-C. This allows for
    Visual Studio-based builds in addition to gcc-based builds.
    This requires at least CMake version 2.8.8. This
    replaces/supplements the cross-compiled set of Visual-Studio
    compatible netCDF libraries introduced in netCDF 4.2.1-rc1.
- Updated buildrequires versions.
* Tue Oct 16 2012 pth@suse.de
- Copy Changes from the release notes to here for the updates to 4.2.1
  and 4.2.1.1
* Sun Aug  5 2012 ocefpaf@gmail.com
- Update to 4.2.1.1:
  * Fix DAP performance bug remotely accessing large files (> 2GiB).
  * Properly escape special characters in CDL output from ncdump for
    netCDF-4 string data.
* Wed Jul 25 2012 ocefpaf@gmail.com
- Update to 4.2.1:
  * Add a specific NC_MMAP mode flag to modify behavior of NC_DISKLESS.
  * Changed the file protections for NC_DISKLESS created files to 0666.
  * Fixed ncdump to report error when an unsupported option is specified.
  * Fixed documentation of CDL char constants in Users Guide and ncgen
    man page.
  * Fixed memory leak detected by valgrind in one of the HDF5 tests.
  For further changes pleaase see the file RELEASE_NOTES in
  /usr/share/doc/packages/netcdf
* Thu Apr 26 2012 behrisch@users.sourceforge.net
- upstream removed Texinfo documentation
* Mon Apr  9 2012 ocefpaf@gmail.com
- Updated to 4.2
  * Fortran and C++ APIs are now in separate packages
- Removed netcdf-dependencies.patch
* Thu Apr  5 2012 jengelh@medozas.de
- Do not require valgrind on arches where it is not available
  (e.g. sparc)
* Fri Mar 16 2012 cfarrell@suse.com
- license update: SUSE-NetCDF
  Use SPDX- proprietary prefix until this license is accepted upstream by
  spdx.org
* Wed Nov 30 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Appropriate rpmgroups for shlib packages
* Tue Nov 29 2011 ocefpaf@gmail.com
- Added explicit hdf5 dependency.
- Rebuild with hdf5 1.8.8
- Some spec file clean-ups.
* Sun Jun 26 2011 ocefpaf@yahoo.com.br
- Added pkgconfig and fflags patches
- Dropped libm patch fixed upstream
- Fixed summary, license info, description
- Created doc and static packages
* Sun Jun 26 2011 ocefpaf@yahoo.com.br
- updated to 4.1.3
* Thu Jun  2 2011 ocefpaf@yahoo.com.br
- rename libnetcdf-devel to netcdf-devel as recommended by pth
* Fri Apr 29 2011 ocefpaf@yahoo.com.br
- updated to version 4.1.2
- added flag --enable-dap for OpenDap support
- updated the patches
* Tue Nov 30 2010 pth@suse.de
- Just fix the casting in px_get to avoid the type-punning warning.
- Add a man page for nc-config.
- Move nc-config and its man page to the devel package.
- Remove the dependency on netcdf from libnetcdf.
- BuildRequire pkgconfig for libnetcdf-devel.
- Declare strlcat if needed.
- Don't use __DATE__ and __TIME__ to reduce the need for recompiling.
* Tue May 19 2009 prusnak@suse.cz
- updated to 4.0.1
  * Added optional arguments to F90 API to nf90_open/create,
    nf90_create_var, and nf90_inquire_variable so that all netCDF-4
    settings may be accomplished with optional arguments, instead
    of separate function calls.
  * Added control of HDF5 chunk cache to allow for user performance
    tuning.
  * Added parallel example program in F90.
  * Changed default chunking to better handle very large variables.
  * Made contiguous the default for fixed size data sets with no
    filters.
  * Fixed bug in nc_inq_ncid; now it returns NC_ENOGRP if the named
    group is not found.
  * Fixed man pages for C and F77 so that netCDF-4 builds will
    result in man pages that document new netCDF-4 functions.
  * Added OPeNDAP support based on a new C-only implementation.
    This is enabled using --enable-dap option and requires libcurl.
    The configure script will attempt to locate libcurl, but if it
    fails, then its location must be specified by the --with-curl
    option.
  * Changed chunksizes to size_t from int.
  * Fixed fill value problem from F77 API.
  * Fixed problems in netcdf-4 files with multi-dimensional
    coordinate variables.
  * Fixed ncgen to properly handle CDL input that uses Windows line
    endings ("\r\n"), instead of getting a syntax error.
  * Added "-s" option to ncdump to display performance
    characterisitics of netCDF-4 files as special virtual attributes,
    such as _Chunking, _DeflateLevel, _Format, and _Endianness.
  * Added "-t" option to ncdump to display times in human readable
    form as strings.  Added code to interpret "calendar" attribute
    according to CF conventions, if present, in displaying
    human-readable times.
  * Added experimental version of ncgen4 capable of generating
    netcdf-4 data files and C code for creating them. In addition,
    it supports the special attributes _Format, etc.
  * Fixed Fortran 90 int64 problems.
  * Rewrote HDF5 read/write code in accordance with performance advice
    from Kent.
  * Fixed memory leaks in gets/puts of HDF5 data.
  * Fixed some broken tests for parallel I/O (i.e. MPI) builds.
  * Fixed some cross-compile problems.
  * Rewrote code which placed bogus errors on the HDF5 error stack,
    trying to open non-existant attributes and variables. Now no HDF5
    errors are seen.
  * Removed man subdirectory. Now man4 subdirectory is used for all
    builds.
  * Changed build so that users with access to parallel make can
    use it.
  * Added experimental support for accessing data through OPeNDAP
    servers using the DAP protocol (use --enable-opendap to build it).
  * Fixed ncdump bugs with array field members of compound type
    variables.  Fixed ncdump bug of assuming default fill value
    for data of type unsigned byte.
* Fri Nov 14 2008 prusnak@suse.cz
- fix wrong delete usage (delete.patch)
* Mon Sep  8 2008 prusnak@suse.cz
- move devel manpages and infopages to -devel subpackage
* Mon Sep  1 2008 prusnak@suse.cz
- disable static libraries
* Fri Aug 22 2008 schwab@suse.de
- Fix makefile dependencies.
* Wed Aug 13 2008 prusnak@suse.cz
- updated to 4.0
  * Introduced the use of HDF5 as a storage layer, which allows use
    of groups, user-defined types, multiple unlimited dimensions,
    compression, data chunking, parallel I/O, and other features
  * In ncdump and ncgen, added CDL support for UTF-8 encoding
    of characters in names and for escaped special chars in names.
    Made sure UTF-8 names are normalized using NFC rules before
    storing or comparing
  * Handle IEEE NaNs and infinities in a platform-independent way
    in ncdump output
  * Added support for ARM representation of doubles
  * Fixed bug in C++ API creating 64-bit offset files
  * Fixed bug for variables larger than 4 GB
  * Changed the configure.ac to build either 3.6.x or 4.x build
    from the same configure.ac
  * Build now checks gfortran version and handles it cleanly,
    also Portland Group in Intel fortran, with various configurations
  * A Fortran netcdf.inc file is now created at build time, based
    on the setting of --disable-v2
  * Documentation has been fixed in several places
  * Upgraded to automake 1.10, autoconf 2.62, and libtool 2.2.2
  * Includes missing Windows Visual Studio build files
  * Fixed missing include of config.h in a C++ test program
  * Fixed maintainer-clean in man directory
  * Fixed --enable-c-only and make check
  * Fixed behavior when opening a zero-length file
  * Many portability enhancements to build cleanly
    on various platforms
  * Turned on some old test programs which were not being used
    in the build
- dropped obsoleted patches:
  * missing-includes.patch (included in update)
* Thu Jan 10 2008 lrupp@suse.de
- use more macros in specfile
- added netcdf-3.6.2-missing_includes.patch
* Mon Aug  6 2007 zpetrova@suse.cz
- split to libnetcdf-4, libnetcdf-devel and netcdf package
  according to Shared library guidelines.
* Mon Jul 30 2007 zpetrova@suse.cz
-update to version 3.6.2
  - Added support for shared libraries (with configure option --enable-shared).
  - Improved performance of byte-swapping loops on little-endian platforms.
  - Added a "-k" option to ncdump and ncgen, for identifying or specifying the kind
    of netCDF file if other than "classic".
  - Made long-threatened change of type of ncbyte in C++ interface from unsigned char
    to signed char, for consistency with C interface.
  - Implemented the C++ API on the netCDF-3 C API instead of the older netCDF-2 API,
    providing automatic numeric type conversion as in the netCDF-3 C interface.
  - Modified to build correctly for gfortran.
  - Added more tests!
  - Fixed minor bugs relating to creation of very small netCDF files.
  - Added support for additional configure options
    (run configure --help for more information).
* Mon May 21 2007 ro@suse.de
- removed cfortran.doc from tarball due to "non-commercial" status
- check in specfile to make sure the file does not reappear
* Thu Oct 19 2006 zpetrova@suse.cz
- update to version 3.6.1
  - updated installation manual
  - netcdf padded small files with zero to 4096 bytes, when they
    were opened and changed. Fixed.
  - small fixes in test suite (return values, names of output files).
  - Doubled arbitrary limits on number of dimensions, variables,
    attributes, and length of names.
  - added new functions, including doc and tests.
  - correctly configure for Intel ifort Fortran compiler on Linux.
* Wed Apr 19 2006 dmueller@suse.de
- build PIC code
* Mon Jan 30 2006 zpetrova@suse.cz
- fixed permissions of libraries, man pages and header files (#131552)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 zpetrova@suse.cz
- update to netcdf-3.6.0-p1
* Thu Sep 29 2005 zpetrova@suse.cz
- add -fno-strict-aliasing
* Tue Jan 11 2005 didge@suse.de
- Updated to new version
- changed URL to the new one
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Fri Apr 23 2004 didge@suse.de
- Updated to new version 3.5.1
- Fixed strict aliasing problem
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue May 13 2003 nashif@suse.de
- added defattr to file list
* Mon Mar 10 2003 nashif@suse.de
- fixed #24975: Build c++ library
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue May 21 2002 ro@suse.de
- complete libdir usage
* Fri Mar  1 2002 nashif@suse.de
- use macro _libdir, fix for s390x build
* Fri Apr 20 2001 nashif@suse.de
- Update to version 3.5.0
- fixed %%files
* Fri Mar 23 2001 nashif@suse.de
- Spec cleanups
- Removed autospec from neededforbuild
* Wed Oct 11 2000 nashif@suse.de
- Use BuildRoot
- Change maintainership to nashif@suse.de
* Tue Jun  6 2000 marquardt@suse.de
- added fortran interface
* Mon May  8 2000 freitag@suse.de
- initial build of version 3.4
